Welcome to caloutils's documentation!
======================================

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   readme
   installation
   contributing
   authors
   history

.. toctree::
   :maxdepth: 2
   :name: Modules
   :caption: Modules

   processing
   variables
   utils


.. Indices and tables
.. ==================
.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`
